function varargout = FilterBKFigure(varargin)
% FILTERBKFIGURE M-file for FilterBKFigure.fig
%      FILTERBKFIGURE, by itself, creates a new FILTERBKFIGURE or raises the existing
%      singleton*.
%
%      H = FILTERBKFIGURE returns the handle to a new FILTERBKFIGURE or the handle to
%      the existing singleton*.
%
%      FILTERBKFIGURE('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in FILTERBKFIGURE.M with the given input arguments.
%
%      FILTERBKFIGURE('Property','Value',...) creates a new FILTERBKFIGURE or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before FilterBKFigure_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to FilterBKFigure_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help FilterBKFigure

% Last Modified by GUIDE v2.5 14-May-2009 20:29:44

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @FilterBKFigure_OpeningFcn, ...
                   'gui_OutputFcn',  @FilterBKFigure_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before FilterBKFigure is made visible.
function FilterBKFigure_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to FilterBKFigure (see VARARGIN)

% Choose default command line output for FilterBKFigure
handles.output = hObject;

handles.baseFigure=varargin{1};
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes FilterBKFigure wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = FilterBKFigure_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double


% --- Executes on button press in FilterHPFigurepushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to FilterHPFigurepushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

global SERIES
global SERIESINDEX
global SERIESTYPE
global SERIESSTAT

handles2=guidata(handles.baseFigure);

index=get(handles2.listbox1,'Value');
SRC=SERIES{index};
RES=BKFILTER(SRC,str2num(get(handles.edit1,'String')),str2num(get(handles.edit2,'String')),str2num(get(handles.edit3,'String')));
RES=RES';

SERIESINDEX=SERIESINDEX+1;
SERIES{SERIESINDEX}=RES;
SERIESTYPE{SERIESINDEX}=[char(SERIESTYPE{index}) ';BKF'];
SERIESSTAT{SERIESINDEX}=getStat(RES);
SERIESSTAT{SERIESINDEX}.fileName=SERIESSTAT{index}.fileName;
saveInfo(handles2,SERIESSTAT{SERIESINDEX});
CD=get(handles2.listbox1,'String');
[CDm,CDn]=size(CD);
CD(CDm+1,:)='FilterBK';
set(handles2.listbox1,'String',CD);
set(handles2.listbox1,'Value',SERIESINDEX);

guidata(handles.baseFigure,handles2);
set(handles2.listbox1,'String',CD);

n=floor((length(SRC)-length(RES))/2);
SRCRES=SRC(n+1:length(SRC)-n)-RES;
SERIESINDEX=SERIESINDEX+1;
SERIES{SERIESINDEX}=SRCRES;
SERIESTYPE{SERIESINDEX}=[char(SERIESTYPE{index}) ';BKF'];
SERIESSTAT{SERIESINDEX}=getStat(SRCRES);
SERIESSTAT{SERIESINDEX}.fileName=SERIESSTAT{index}.fileName;
saveInfo(handles2,SERIESSTAT{SERIESINDEX});
CD=get(handles2.listbox1,'String');
[CDm,CDn]=size(CD);
CD(CDm+1,:)='CycleCBK';
set(handles2.listbox1,'String',CD);
set(handles2.listbox1,'Value',SERIESINDEX);

guidata(handles.baseFigure,handles2);
set(handles2.listbox1,'String',CD);


% --- Executes during object creation, after setting all properties.
function edit2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function edit2_Callback(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit2 as text
%        str2double(get(hObject,'String')) returns contents of edit2 as a double


% --- Executes during object creation, after setting all properties.
function edit3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function edit3_Callback(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3 as text
%        str2double(get(hObject,'String')) returns contents of edit3 as a double


